@@ -1,8 +1,8 @@
-import re
 from cbv.views.base import TemplateResponseMixin, View
 from django.core.exceptions import ImproperlyConfigured, ObjectDoesNotExist
 from django.http import Http404
 from django.utils.encoding import smart_str
+from django.utils.translation import ugettext as _
 
 
 class SingleObjectMixin(object):
@@ -40,14 +40,16 @@ class SingleObjectMixin(object):
         # If none of those are defined, it's an error.
         else:
             raise AttributeError(u"Generic detail view %s must be called with "
-                                 u"either an object id or a slug."
+                                 u"either an object pk or a slug."
                                  % self.__class__.__name__)
 
         try:
             obj = queryset.get()
         except ObjectDoesNotExist:
-            raise Http404(u"No %s found matching the query" %
-                          (queryset.model._meta.verbose_name))
+            raise Http404(
+                _(u"No %(verbose_name)s found matching the query") % {
+                    'verbose_name': queryset.model._meta.verbose_name,
+            })
         return obj
 
     def get_queryset(self):
@@ -62,7 +64,7 @@ class SingleObjectMixin(object):
                 raise ImproperlyConfigured(
                     u"%(cls)s is missing a queryset. Define %(cls)s.model, "
                     u"%(cls)s.queryset, or override %(cls)s.get_object()." % {
-                        'cls': self.__class__.__name__ }
+                        'cls': self.__class__.__name__}
                     )
         return self.queryset._clone()
 
@@ -79,8 +81,7 @@ class SingleObjectMixin(object):
         if self.context_object_name:
             return self.context_object_name
         elif hasattr(obj, '_meta'):
-            return smart_str(re.sub('[^a-zA-Z0-9]+', '_',
-                    obj._meta.verbose_name.lower()))
+            return smart_str(obj._meta.verbose_name.lower())
         else:
             return None
 
@@ -108,8 +109,13 @@ class SingleObjectTemplateResponseMixin(TemplateResponseMixin):
         Return a list of template names to be used for the request. Must return
         a list. May not be called if get_template is overridden.
         """
-        sup = super(SingleObjectTemplateResponseMixin, self)
-        names = sup.get_template_names()
+        try:
+            names = super(SingleObjectTemplateResponseMixin,
+                          self).get_template_names()
+        except ImproperlyConfigured:
+            # If template_name isn't specified, it's not a problem --
+            # we just start with an empty list.
+            names = []
 
         # If self.template_name_field is set, grab the value of the field
         # of that name from the object; this is the most specific template
@@ -141,5 +147,6 @@ class DetailView(SingleObjectTemplateResponseMixin, BaseDetailView):
     Render a "detail" view of an object.
 
     By default this is a model instance looked up from `self.queryset`, but the
-    view will support display of *any* object by overriding `self.get_object()`.
+    view will support display of *any* object by overriding
+    `self.get_object()`.
     """
